@@ -94,60 +94,60 @@ void T3MemoryDeInit(T3Memory * mem)
 
 //////////////////////////////////////////////////////////////////////////////
 
-Dummy * DummyInit(u32 s)
+Dummy * DummyInit(UNUSED u32 s)
 {
    return NULL;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void DummyDeInit(Dummy * d)
+void DummyDeInit(UNUSED Dummy * d)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u8 FASTCALL UnhandledMemoryReadByte(u32 addr)
+u8 FASTCALL UnhandledMemoryReadByte(USED_IF_DEBUG u32 addr)
 {
-   fprintf(stderr, "Unhandled byte read %08X\n", (unsigned int)addr);
+   LOG("Unhandled byte read %08X\n", (unsigned int)addr);
    return 0;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL UnhandledMemoryReadWord(u32 addr)
+u16 FASTCALL UnhandledMemoryReadWord(USED_IF_DEBUG u32 addr)
 {
-   fprintf(stderr, "Unhandled word read %08X\n", (unsigned int)addr);
+   LOG("Unhandled word read %08X\n", (unsigned int)addr);
    return 0;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL UnhandledMemoryReadLong(u32 addr)
+u32 FASTCALL UnhandledMemoryReadLong(USED_IF_DEBUG u32 addr)
 {
-   fprintf(stderr, "Unhandled long read %08X\n", (unsigned int)addr);
+   LOG("Unhandled long read %08X\n", (unsigned int)addr);
    return 0;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL UnhandledMemoryWriteByte(u32 addr, u8 val)
+void FASTCALL UnhandledMemoryWriteByte(USED_IF_DEBUG u32 addr, UNUSED u8 val)
 {
-   fprintf(stderr, "Unhandled byte write %08X\n", (unsigned int)addr);
+   LOG("Unhandled byte write %08X\n", (unsigned int)addr);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL UnhandledMemoryWriteWord(u32 addr, u16 val)
+void FASTCALL UnhandledMemoryWriteWord(USED_IF_DEBUG u32 addr, UNUSED u16 val)
 {
-   fprintf(stderr, "Unhandled word write %08X\n", (unsigned int)addr);
+   LOG("Unhandled word write %08X\n", (unsigned int)addr);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL UnhandledMemoryWriteLong(u32 addr, u32 val)
+void FASTCALL UnhandledMemoryWriteLong(USED_IF_DEBUG u32 addr, UNUSED u32 val)
 {
-   fprintf(stderr, "Unhandled long write %08X\n", (unsigned int)addr);
+   LOG("Unhandled long write %08X\n", (unsigned int)addr);
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -257,14 +257,14 @@ u32 FASTCALL BiosRomMemoryReadLong(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BiosRomMemoryWriteByte(u32 addr, u8 val)
+void FASTCALL BiosRomMemoryWriteByte(UNUSED u32 addr, UNUSED u8 val)
 {
    // read-only
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BiosRomMemoryWriteWord(u32 addr, u16 val)
+void FASTCALL BiosRomMemoryWriteWord(UNUSED u32 addr, UNUSED u16 val)
 {
    // read-only
 }
@@ -272,7 +272,7 @@ void FASTCALL BiosRomMemoryWriteWord(u32 addr, u16 val)
 //////////////////////////////////////////////////////////////////////////////
 
 
-void FASTCALL BiosRomMemoryWriteLong(u32 addr, u32 val)
+void FASTCALL BiosRomMemoryWriteLong(UNUSED u32 addr, UNUSED u32 val)
 {
    // read-only
 }
@@ -286,7 +286,7 @@ u8 FASTCALL BupRamMemoryReadByte(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL BupRamMemoryReadWord(u32 addr)
+u16 FASTCALL BupRamMemoryReadWord(USED_IF_DEBUG u32 addr)
 {
    LOG("bup\t: BackupRam read word - %08X\n", addr);
    return 0;
@@ -294,7 +294,7 @@ u16 FASTCALL BupRamMemoryReadWord(u32 addr)
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL BupRamMemoryReadLong(u32 addr)
+u32 FASTCALL BupRamMemoryReadLong(USED_IF_DEBUG u32 addr)
 {
    LOG("bup\t: BackupRam read long - %08X\n", addr);
    return 0;
@@ -309,14 +309,14 @@ void FASTCALL BupRamMemoryWriteByte(u32 addr, u8 val)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BupRamMemoryWriteWord(u32 addr, u16 val)
+void FASTCALL BupRamMemoryWriteWord(USED_IF_DEBUG u32 addr, UNUSED u16 val)
 {
    LOG("bup\t: BackupRam write word - %08X\n", addr);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL BupRamMemoryWriteLong(u32 addr, u32 val)
+void FASTCALL BupRamMemoryWriteLong(USED_IF_DEBUG u32 addr, UNUSED u32 val)
 {
    LOG("bup\t: BackupRam write long - %08X\n", addr);
 }
@@ -935,6 +935,7 @@ int YabSaveState(const char *filename)
    u32 i;
    FILE *fp;
    int offset;
+   IOCheck_struct check;
 
    if ((fp = fopen(filename, "wb")) == NULL)
       return -1;
@@ -951,11 +952,11 @@ int YabSaveState(const char *filename)
 
    // Write version(fix me)
    i = 1;
-   fwrite((void *)&i, sizeof(i), 1, fp);
+   ywrite(&check, (void *)&i, sizeof(i), 1, fp);
 
    // Skip the next 4 bytes for now
    i = 0;
-   fwrite((void *)&i, sizeof(i), 1, fp);
+   ywrite(&check, (void *)&i, sizeof(i), 1, fp);
 
    // Go through each area and write each state
    i += CartSaveState(fp);
@@ -971,25 +972,25 @@ int YabSaveState(const char *filename)
    offset = StateWriteHeader(fp, "OTHR", 1);
 
    // Other data
-   fwrite((void *)BupRam, 0x10000, 1, fp); // do we really want to save this?
-   fwrite((void *)HighWram, 0x100000, 1, fp);
-   fwrite((void *)LowWram, 0x100000, 1, fp);
+   ywrite(&check, (void *)BupRam, 0x10000, 1, fp); // do we really want to save this?
+   ywrite(&check, (void *)HighWram, 0x100000, 1, fp);
+   ywrite(&check, (void *)LowWram, 0x100000, 1, fp);
 
-   fwrite((void *)&yabsys.DecilineCount, sizeof(int), 1, fp);
-   fwrite((void *)&yabsys.LineCount, sizeof(int), 1, fp);
-   fwrite((void *)&yabsys.VBlankLineCount, sizeof(int), 1, fp);
-   fwrite((void *)&yabsys.MaxLineCount, sizeof(int), 1, fp);
-   fwrite((void *)&yabsys.DecilineStop, sizeof(int), 1, fp);
-   fwrite((void *)&yabsys.Duf, sizeof(int), 1, fp);
-   fwrite((void *)&yabsys.CycleCountII, sizeof(u32), 1, fp);
-   fwrite((void *)&yabsys.CurSH2FreqType, sizeof(int), 1, fp);
-   fwrite((void *)&yabsys.IsPal, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.DecilineCount, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.LineCount, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.VBlankLineCount, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.MaxLineCount, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.DecilineStop, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.Duf, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.CycleCountII, sizeof(u32), 1, fp);
+   ywrite(&check, (void *)&yabsys.CurSH2FreqType, sizeof(int), 1, fp);
+   ywrite(&check, (void *)&yabsys.IsPal, sizeof(int), 1, fp);
 
    i += StateFinishHeader(fp, offset);
 
    // Go back and update size
    fseek(fp, 8, SEEK_SET);
-   fwrite((void *)&i, sizeof(i), 1, fp);
+   ywrite(&check, (void *)&i, sizeof(i), 1, fp);
 
    fclose(fp);
 
@@ -1004,12 +1005,13 @@ int YabLoadState(const char *filename)
    char id[3];
    u8 endian;
    int version, size, chunksize;
+   IOCheck_struct check;
 
    if ((fp = fopen(filename, "rb")) == NULL)
       return -1;
 
    // Read signature
-   fread((void *)id, 1, 3, fp);
+   yread(&check, (void *)id, 1, 3, fp);
 
    if (strncmp(id, "YSS", 3) != 0)
    {
@@ -1018,9 +1020,9 @@ int YabLoadState(const char *filename)
    }
 
    // Read header
-   fread((void *)&endian, 1, 1, fp);
-   fread((void *)&version, 4, 1, fp);
-   fread((void *)&size, 4, 1, fp);
+   yread(&check, (void *)&endian, 1, 1, fp);
+   yread(&check, (void *)&version, 4, 1, fp);
+   yread(&check, (void *)&size, 4, 1, fp);
 
 #ifdef WORDS_BIGENDIAN
    if (endian == 1)
@@ -1136,19 +1138,19 @@ int YabLoadState(const char *filename)
       return -3;
    }
    // Other data
-   fread((void *)BupRam, 0x10000, 1, fp);
-   fread((void *)HighWram, 0x100000, 1, fp);
-   fread((void *)LowWram, 0x100000, 1, fp);
+   yread(&check, (void *)BupRam, 0x10000, 1, fp);
+   yread(&check, (void *)HighWram, 0x100000, 1, fp);
+   yread(&check, (void *)LowWram, 0x100000, 1, fp);
 
-   fread((void *)&yabsys.DecilineCount, sizeof(int), 1, fp);
-   fread((void *)&yabsys.LineCount, sizeof(int), 1, fp);
-   fread((void *)&yabsys.VBlankLineCount, sizeof(int), 1, fp);
-   fread((void *)&yabsys.MaxLineCount, sizeof(int), 1, fp);
-   fread((void *)&yabsys.DecilineStop, sizeof(int), 1, fp);
-   fread((void *)&yabsys.Duf, sizeof(int), 1, fp);
-   fread((void *)&yabsys.CycleCountII, sizeof(u32), 1, fp);
-   fread((void *)&yabsys.CurSH2FreqType, sizeof(int), 1, fp);
-   fread((void *)&yabsys.IsPal, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.DecilineCount, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.LineCount, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.VBlankLineCount, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.MaxLineCount, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.DecilineStop, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.Duf, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.CycleCountII, sizeof(u32), 1, fp);
+   yread(&check, (void *)&yabsys.CurSH2FreqType, sizeof(int), 1, fp);
+   yread(&check, (void *)&yabsys.IsPal, sizeof(int), 1, fp);
 
    fclose(fp);
 
@@ -1196,19 +1198,19 @@ int MappedMemoryAddMatch(u32 addr, u32 val, int searchtype, result_struct *resul
 
 static INLINE int SearchIncrementAndCheckBounds(result_struct *prevresults,
                                                 u32 *maxresults,
-                                                u32 numresults, u32 i,
+                                                u32 numresults, u32 *i,
                                                 u32 inc, u32 *newaddr,
                                                 u32 endaddr)
 {
    if (prevresults)
    {
-      if (i >= maxresults[0])
+      if (i[0] >= maxresults[0])
       {
          maxresults[0] = numresults;
          return 1;
       }
-      newaddr[0] = prevresults[i].addr;
-      i++;
+      newaddr[0] = prevresults[i[0]].addr;
+      i[0]++;
    }
    else
    {
@@ -1234,7 +1236,6 @@ static int SearchString(u32 startaddr, u32 endaddr, int searchtype,
    u32 *buf32=NULL;
    u32 buflen=0;
    u32 counter;
-   u16 lastval=0;
    u32 addr;
    u32 numresults=0;
 
@@ -1430,7 +1431,7 @@ result_struct *MappedMemorySearch(u32 startaddr, u32 endaddr, int searchtype,
              if (issigned)
                 val = (s8)val;
 
-             if (SearchIncrementAndCheckBounds(prevresults, maxresults, numresults, i, addr+1, &newaddr, endaddr))
+             if (SearchIncrementAndCheckBounds(prevresults, maxresults, numresults, &i, addr+1, &newaddr, endaddr))
                 return results;
              break;
           case SEARCHWORD:
@@ -1439,13 +1440,13 @@ result_struct *MappedMemorySearch(u32 startaddr, u32 endaddr, int searchtype,
              if (issigned)
                 val = (s16)val;
 
-             if (SearchIncrementAndCheckBounds(prevresults, maxresults, numresults, i, addr+2, &newaddr, endaddr))
+             if (SearchIncrementAndCheckBounds(prevresults, maxresults, numresults, &i, addr+2, &newaddr, endaddr))
                 return results;
              break;
           case SEARCHLONG:
              val = MappedMemoryReadLong(addr);
 
-             if (SearchIncrementAndCheckBounds(prevresults, maxresults, numresults, i, addr+4, &newaddr, endaddr))
+             if (SearchIncrementAndCheckBounds(prevresults, maxresults, numresults, &i, addr+4, &newaddr, endaddr))
                 return results;
              break;
           default:
