@@ -1743,7 +1743,7 @@ void FASTCALL ScuWriteByte(u32 addr, u8 val) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL ScuWriteWord(u32 addr, u16 val) {
+void FASTCALL ScuWriteWord(u32 addr, UNUSED u16 val) {
    addr &= 0xFF;
    LOG("Unhandled SCU Register word write %08X\n", addr);
 }
@@ -1931,7 +1931,7 @@ void FASTCALL ScuWriteLong(u32 addr, u32 val) {
 
 void ScuTestInterruptMask()
 {
-   int i, i2;
+   unsigned int i, i2;
 
    // Handle SCU interrupts
    for (i = 0; i < ScuRegs->NumberOfInterrupts; i++)
@@ -2202,27 +2202,30 @@ void ScuSendExternalInterrupt15(void) {
 int ScuSaveState(FILE *fp)
 {
    int offset;
+   IOCheck_struct check;
 
    offset = StateWriteHeader(fp, "SCU ", 1);
 
    // Write registers and internal variables
-   fwrite((void *)ScuRegs, sizeof(Scu), 1, fp);
+   ywrite(&check, (void *)ScuRegs, sizeof(Scu), 1, fp);
 
    // Write DSP area
-   fwrite((void *)ScuDsp, sizeof(scudspregs_struct), 1, fp);
+   ywrite(&check, (void *)ScuDsp, sizeof(scudspregs_struct), 1, fp);
 
    return StateFinishHeader(fp, offset);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-int ScuLoadState(FILE *fp, int version, int size)
+int ScuLoadState(FILE *fp, UNUSED int version, int size)
 {
+   IOCheck_struct check;
+
    // Read registers and internal variables
-   fread((void *)ScuRegs, sizeof(Scu), 1, fp);
+   yread(&check, (void *)ScuRegs, sizeof(Scu), 1, fp);
 
    // Read DSP area
-   fread((void *)ScuDsp, sizeof(scudspregs_struct), 1, fp);
+   yread(&check, (void *)ScuDsp, sizeof(scudspregs_struct), 1, fp);
 
    return size;
 }
