@@ -313,6 +313,8 @@ void SmpcINTBACKPeripheral(void) {
      port2 = &PORTDATA2;
      memcpy(&SmpcInternalVars->port1, port1, sizeof(PortData_struct));
      memcpy(&SmpcInternalVars->port2, port2, sizeof(PortData_struct));
+     PerFlush(&PORTDATA1);
+     PerFlush(&PORTDATA2);
      SmpcInternalVars->port1.offset = 0;
      SmpcInternalVars->port2.offset = 0;
   }
@@ -523,7 +525,7 @@ u8 FASTCALL SmpcReadByte(u32 addr) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-u16 FASTCALL SmpcReadWord(u32 addr) {
+u16 FASTCALL SmpcReadWord(USED_IF_SMPC_DEBUG u32 addr) {
    // byte access only
    SMPCLOG("smpc\t: SMPC register read word - %08X\n", addr);
    return 0;
@@ -531,7 +533,7 @@ u16 FASTCALL SmpcReadWord(u32 addr) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-u32 FASTCALL SmpcReadLong(u32 addr) {
+u32 FASTCALL SmpcReadLong(USED_IF_SMPC_DEBUG u32 addr) {
    // byte access only
    SMPCLOG("smpc\t: SMPC register read long - %08X\n", addr);
    return 0;
@@ -668,14 +670,14 @@ void FASTCALL SmpcWriteByte(u32 addr, u8 val) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL SmpcWriteWord(u32 addr, u16 val) {
+void FASTCALL SmpcWriteWord(USED_IF_SMPC_DEBUG u32 addr, UNUSED u16 val) {
    // byte access only
    SMPCLOG("smpc\t: SMPC register write word - %08X\n", addr);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL SmpcWriteLong(u32 addr, u32 val) {
+void FASTCALL SmpcWriteLong(USED_IF_SMPC_DEBUG u32 addr, UNUSED u32 val) {
    // byte access only
    SMPCLOG("smpc\t: SMPC register write long - %08X\n", addr);
 }
@@ -685,22 +687,23 @@ void FASTCALL SmpcWriteLong(u32 addr, u32 val) {
 int SmpcSaveState(FILE *fp)
 {
    int offset;
+   IOCheck_struct check;
 
-   offset = StateWriteHeader(fp, "SMPC", 1);
+   offset = StateWriteHeader(fp, "SMPC", 2);
 
    // Write registers
-   fwrite((void *)SmpcRegs->IREG, sizeof(u8), 7, fp);
-   fwrite((void *)&SmpcRegs->COMREG, sizeof(u8), 1, fp);
-   fwrite((void *)SmpcRegs->OREG, sizeof(u8), 32, fp);
-   fwrite((void *)&SmpcRegs->SR, sizeof(u8), 1, fp);
-   fwrite((void *)&SmpcRegs->SF, sizeof(u8), 1, fp);
-   fwrite((void *)SmpcRegs->PDR, sizeof(u8), 2, fp);
-   fwrite((void *)SmpcRegs->DDR, sizeof(u8), 2, fp);
-   fwrite((void *)&SmpcRegs->IOSEL, sizeof(u8), 1, fp);
-   fwrite((void *)&SmpcRegs->EXLE, sizeof(u8), 1, fp);
+   ywrite(&check, (void *)SmpcRegs->IREG, sizeof(u8), 7, fp);
+   ywrite(&check, (void *)&SmpcRegs->COMREG, sizeof(u8), 1, fp);
+   ywrite(&check, (void *)SmpcRegs->OREG, sizeof(u8), 32, fp);
+   ywrite(&check, (void *)&SmpcRegs->SR, sizeof(u8), 1, fp);
+   ywrite(&check, (void *)&SmpcRegs->SF, sizeof(u8), 1, fp);
+   ywrite(&check, (void *)SmpcRegs->PDR, sizeof(u8), 2, fp);
+   ywrite(&check, (void *)SmpcRegs->DDR, sizeof(u8), 2, fp);
+   ywrite(&check, (void *)&SmpcRegs->IOSEL, sizeof(u8), 1, fp);
+   ywrite(&check, (void *)&SmpcRegs->EXLE, sizeof(u8), 1, fp);
 
    // Write internal variables
-   fwrite((void *)SmpcInternalVars, sizeof(SmpcInternal), 1, fp);
+   ywrite(&check, (void *)SmpcInternalVars, sizeof(SmpcInternal), 1, fp);
 
    // Write ID's of currently emulated peripherals(fix me)
 
@@ -711,19 +714,33 @@ int SmpcSaveState(FILE *fp)
 
 int SmpcLoadState(FILE *fp, int version, int size)
 {
+   IOCheck_struct check;
+
    // Read registers
-   fread((void *)SmpcRegs->IREG, sizeof(u8), 7, fp);
-   fread((void *)&SmpcRegs->COMREG, sizeof(u8), 1, fp);
-   fread((void *)SmpcRegs->OREG, sizeof(u8), 32, fp);
-   fread((void *)&SmpcRegs->SR, sizeof(u8), 1, fp);
-   fread((void *)&SmpcRegs->SF, sizeof(u8), 1, fp);
-   fread((void *)SmpcRegs->PDR, sizeof(u8), 2, fp);
-   fread((void *)SmpcRegs->DDR, sizeof(u8), 2, fp);
-   fread((void *)&SmpcRegs->IOSEL, sizeof(u8), 1, fp);
-   fread((void *)&SmpcRegs->EXLE, sizeof(u8), 1, fp);
+   yread(&check, (void *)SmpcRegs->IREG, sizeof(u8), 7, fp);
+   yread(&check, (void *)&SmpcRegs->COMREG, sizeof(u8), 1, fp);
+   yread(&check, (void *)SmpcRegs->OREG, sizeof(u8), 32, fp);
+   yread(&check, (void *)&SmpcRegs->SR, sizeof(u8), 1, fp);
+   yread(&check, (void *)&SmpcRegs->SF, sizeof(u8), 1, fp);
+   yread(&check, (void *)SmpcRegs->PDR, sizeof(u8), 2, fp);
+   yread(&check, (void *)SmpcRegs->DDR, sizeof(u8), 2, fp);
+   yread(&check, (void *)&SmpcRegs->IOSEL, sizeof(u8), 1, fp);
+   yread(&check, (void *)&SmpcRegs->EXLE, sizeof(u8), 1, fp);
 
    // Read internal variables
-   fread((void *)SmpcInternalVars, sizeof(SmpcInternal), 1, fp);
+   if (version == 1)
+   {
+      // This handles the problem caused by the version not being incremented
+      // when SmpcInternal was changed
+      if ((size - 48) == sizeof(SmpcInternal))
+         yread(&check, (void *)SmpcInternalVars, sizeof(SmpcInternal), 1, fp);
+      else if ((size - 48) == 24)
+         yread(&check, (void *)SmpcInternalVars, 24, 1, fp);
+      else
+         fseek(fp, size - 48, SEEK_CUR);
+   }
+   else
+      yread(&check, (void *)SmpcInternalVars, sizeof(SmpcInternal), 1, fp);
 
    // Read ID's of currently emulated peripherals(fix me)
 
