@@ -257,7 +257,7 @@ u32 FASTCALL Vdp1ReadLong(u32 addr) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL Vdp1WriteByte(u32 addr, u8 val) {
+void FASTCALL Vdp1WriteByte(u32 addr, UNUSED u8 val) {
    addr &= 0xFF;
    LOG("trying to byte-write a Vdp1 register - %08X\n", addr);
 }
@@ -295,7 +295,7 @@ void FASTCALL Vdp1WriteWord(u32 addr, u16 val) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL Vdp1WriteLong(u32 addr, u32 val) {
+void FASTCALL Vdp1WriteLong(u32 addr, UNUSED u32 val) {
    addr &= 0xFF;
    LOG("trying to long-write a Vdp1 register - %08X\n", addr);
 }
@@ -513,27 +513,30 @@ void FASTCALL Vdp1ReadCommand(vdp1cmd_struct *cmd, u32 addr) {
 int Vdp1SaveState(FILE *fp)
 {
    int offset;
+   IOCheck_struct check;
 
    offset = StateWriteHeader(fp, "VDP1", 1);
 
    // Write registers
-   fwrite((void *)Vdp1Regs, sizeof(Vdp1), 1, fp);
+   ywrite(&check, (void *)Vdp1Regs, sizeof(Vdp1), 1, fp);
 
    // Write VDP1 ram
-   fwrite((void *)Vdp1Ram, 0x80000, 1, fp);
+   ywrite(&check, (void *)Vdp1Ram, 0x80000, 1, fp);
 
    return StateFinishHeader(fp, offset);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-int Vdp1LoadState(FILE *fp, int version, int size)
+int Vdp1LoadState(FILE *fp, UNUSED int version, int size)
 {
+   IOCheck_struct check;
+
    // Read registers
-   fread((void *)Vdp1Regs, sizeof(Vdp1), 1, fp);
+   yread(&check, (void *)Vdp1Regs, sizeof(Vdp1), 1, fp);
 
    // Read VDP1 ram
-   fread((void *)Vdp1Ram, 0x80000, 1, fp);
+   yread(&check, (void *)Vdp1Ram, 0x80000, 1, fp);
 
    return size;
 }
@@ -581,6 +584,8 @@ u32 Vdp1DebugGetCommandNumberAddr(u32 number)
             break;
       }
 
+      if (addr > 0x7FFE0)
+         return 0xFFFFFFFF;
       command = T1ReadWord(Vdp1Ram, addr);
       commandCounter++;    
    }
@@ -1286,11 +1291,7 @@ void FASTCALL VIDDummyVdp2SetPriorityNBG1(int priority);
 void FASTCALL VIDDummyVdp2SetPriorityNBG2(int priority);
 void FASTCALL VIDDummyVdp2SetPriorityNBG3(int priority);
 void FASTCALL VIDDummyVdp2SetPriorityRBG0(int priority);
-void VIDDummyVdp2ToggleDisplayNBG0(void);
-void VIDDummyVdp2ToggleDisplayNBG1(void);
-void VIDDummyVdp2ToggleDisplayNBG2(void);
-void VIDDummyVdp2ToggleDisplayNBG3(void);
-void VIDDummyVdp2ToggleDisplayRBG0(void);
+void VIDDummyOnScreenDebugMessage(char * string, ...);
 
 
 VideoInterface_struct VIDDummy = {
@@ -1322,11 +1323,7 @@ VIDDummyVdp2SetPriorityNBG1,
 VIDDummyVdp2SetPriorityNBG2,
 VIDDummyVdp2SetPriorityNBG3,
 VIDDummyVdp2SetPriorityRBG0,
-VIDDummyVdp2ToggleDisplayNBG0,
-VIDDummyVdp2ToggleDisplayNBG1,
-VIDDummyVdp2ToggleDisplayNBG2,
-VIDDummyVdp2ToggleDisplayNBG3,
-VIDDummyVdp2ToggleDisplayRBG0
+VIDDummyOnScreenDebugMessage
 };
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1344,7 +1341,7 @@ void VIDDummyDeInit(void)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void VIDDummyResize(unsigned int i, unsigned int j, int on)
+void VIDDummyResize(UNUSED unsigned int i, UNUSED unsigned int j, UNUSED int on)
 {
 }
 
@@ -1455,69 +1452,42 @@ void VIDDummyVdp2DrawScreens(void)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void VIDDummyVdp2SetResolution(u16 TVMD)
+void VIDDummyVdp2SetResolution(UNUSED u16 TVMD)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL VIDDummyVdp2SetPriorityNBG0(int priority)
+void FASTCALL VIDDummyVdp2SetPriorityNBG0(UNUSED int priority)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL VIDDummyVdp2SetPriorityNBG1(int priority)
+void FASTCALL VIDDummyVdp2SetPriorityNBG1(UNUSED int priority)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL VIDDummyVdp2SetPriorityNBG2(int priority)
+void FASTCALL VIDDummyVdp2SetPriorityNBG2(UNUSED int priority)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL VIDDummyVdp2SetPriorityNBG3(int priority)
+void FASTCALL VIDDummyVdp2SetPriorityNBG3(UNUSED int priority)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL VIDDummyVdp2SetPriorityRBG0(int priority)
+void FASTCALL VIDDummyVdp2SetPriorityRBG0(UNUSED int priority)
 {
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-void VIDDummyVdp2ToggleDisplayNBG0(void)
+void VIDDummyOnScreenDebugMessage(UNUSED char * string, ...)
 {
 }
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDDummyVdp2ToggleDisplayNBG1(void)
-{
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDDummyVdp2ToggleDisplayNBG2(void)
-{
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDDummyVdp2ToggleDisplayNBG3(void)
-{
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDDummyVdp2ToggleDisplayRBG0(void)
-{
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
