@@ -30,6 +30,7 @@ u8 * Vdp2Ram;
 u8 * Vdp2ColorRam;
 Vdp2 * Vdp2Regs;
 Vdp2Internal_struct Vdp2Internal;
+Vdp2External_struct Vdp2External;
 
 static int autoframeskipenab=0;
 static int framestoskip=0;
@@ -246,6 +247,8 @@ void Vdp2Reset(void) {
 
    yabsys.VBlankLineCount = 224;
    Vdp2Internal.ColorMode = 0;
+
+   Vdp2External.disptoggle = 0xFF;
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -458,7 +461,7 @@ u32 FASTCALL Vdp2ReadLong(u32 addr) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-void FASTCALL Vdp2WriteByte(u32 addr, u8 val) {
+void FASTCALL Vdp2WriteByte(u32 addr, UNUSED u8 val) {
    LOG("VDP2 register byte write = %08X\n", addr);
    addr &= 0x1FF;
 }
@@ -1230,39 +1233,42 @@ void FASTCALL Vdp2WriteLong(u32 addr, u32 val) {
 int Vdp2SaveState(FILE *fp)
 {
    int offset;
+   IOCheck_struct check;
 
    offset = StateWriteHeader(fp, "VDP2", 1);
 
    // Write registers
-   fwrite((void *)Vdp2Regs, sizeof(Vdp2), 1, fp);
+   ywrite(&check, (void *)Vdp2Regs, sizeof(Vdp2), 1, fp);
 
    // Write VDP2 ram
-   fwrite((void *)Vdp2Ram, 0x80000, 1, fp);
+   ywrite(&check, (void *)Vdp2Ram, 0x80000, 1, fp);
 
    // Write CRAM
-   fwrite((void *)Vdp2ColorRam, 0x1000, 1, fp);
+   ywrite(&check, (void *)Vdp2ColorRam, 0x1000, 1, fp);
 
    // Write internal variables
-   fwrite((void *)&Vdp2Internal, sizeof(Vdp2Internal_struct), 1, fp);
+   ywrite(&check, (void *)&Vdp2Internal, sizeof(Vdp2Internal_struct), 1, fp);
 
    return StateFinishHeader(fp, offset);
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-int Vdp2LoadState(FILE *fp, int version, int size)
+int Vdp2LoadState(FILE *fp, UNUSED int version, int size)
 {
+   IOCheck_struct check;
+
    // Read registers
-   fread((void *)Vdp2Regs, sizeof(Vdp2), 1, fp);
+   yread(&check, (void *)Vdp2Regs, sizeof(Vdp2), 1, fp);
 
    // Read VDP2 ram
-   fread((void *)Vdp2Ram, 0x80000, 1, fp);
+   yread(&check, (void *)Vdp2Ram, 0x80000, 1, fp);
 
    // Read CRAM
-   fread((void *)Vdp2ColorRam, 0x1000, 1, fp);
+   yread(&check, (void *)Vdp2ColorRam, 0x1000, 1, fp);
 
    // Read internal variables
-   fread((void *)&Vdp2Internal, sizeof(Vdp2Internal_struct), 1, fp);
+   yread(&check, (void *)&Vdp2Internal, sizeof(Vdp2Internal_struct), 1, fp);
 
    VIDCore->Vdp2SetResolution(Vdp2Regs->TVMD);
    VIDCore->Vdp2SetPriorityNBG0(Vdp2Regs->PRINA & 0x7);
@@ -1278,35 +1284,35 @@ int Vdp2LoadState(FILE *fp, int version, int size)
 
 void ToggleNBG0(void)
 {
-   VIDCore->Vdp2ToggleDisplayNBG0();
+   Vdp2External.disptoggle ^= 0x1;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 void ToggleNBG1(void)
 {
-   VIDCore->Vdp2ToggleDisplayNBG1();
+   Vdp2External.disptoggle ^= 0x2;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 void ToggleNBG2(void)
 {
-   VIDCore->Vdp2ToggleDisplayNBG2();
+   Vdp2External.disptoggle ^= 0x4;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 void ToggleNBG3(void)
 {
-   VIDCore->Vdp2ToggleDisplayNBG3();
+   Vdp2External.disptoggle ^= 0x8;
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
 void ToggleRBG0(void)
 {
-   VIDCore->Vdp2ToggleDisplayRBG0();
+   Vdp2External.disptoggle ^= 0x10;
 }
 
 //////////////////////////////////////////////////////////////////////////////
