@@ -1657,7 +1657,7 @@ void Vdp2DebugStatsGeneral(char *outstring, int *isenabled)
 
 //////////////////////////////////////////////////////////////////////////////
 
-static u32 FASTCALL DoNothing(void *info, u32 pixel)
+static u32 FASTCALL DoNothing(UNUSED void *info, u32 pixel)
 {
    return pixel;
 }
