@@ -88,11 +88,6 @@ void FASTCALL VIDSoftVdp2SetPriorityNBG1(int priority);
 void FASTCALL VIDSoftVdp2SetPriorityNBG2(int priority);
 void FASTCALL VIDSoftVdp2SetPriorityNBG3(int priority);
 void FASTCALL VIDSoftVdp2SetPriorityRBG0(int priority);
-void VIDSoftVdp2ToggleDisplayNBG0(void);
-void VIDSoftVdp2ToggleDisplayNBG1(void);
-void VIDSoftVdp2ToggleDisplayNBG2(void);
-void VIDSoftVdp2ToggleDisplayNBG3(void);
-void VIDSoftVdp2ToggleDisplayRBG0(void);
 void VIDSoftOnScreenDebugMessage(char *string, ...);
 void VIDSoftVdp1SwapFrameBuffer(void);
 void VIDSoftVdp1EraseFrameBuffer(void);
@@ -126,11 +121,6 @@ VIDSoftVdp2SetPriorityNBG1,
 VIDSoftVdp2SetPriorityNBG2,
 VIDSoftVdp2SetPriorityNBG3,
 VIDSoftVdp2SetPriorityRBG0,
-VIDSoftVdp2ToggleDisplayNBG0,
-VIDSoftVdp2ToggleDisplayNBG1,
-VIDSoftVdp2ToggleDisplayNBG2,
-VIDSoftVdp2ToggleDisplayNBG3,
-VIDSoftVdp2ToggleDisplayRBG0,
 VIDSoftOnScreenDebugMessage,
 };
 
@@ -151,7 +141,6 @@ static int vdp1pixelsize;
 static int vdp1spritetype;
 int vdp2width;
 int vdp2height;
-static int vdp2disptoggle=0xFF;
 static int nbg0priority=0;
 static int nbg1priority=0;
 static int nbg2priority=0;
@@ -311,11 +300,14 @@ static void Vdp2PatternAddr(vdp2draw_struct *info)
       info->charaddr &= 0x3FFF;
 
    info->charaddr *= 0x20; // selon Runik
+   if (info->specialprimode == 1) {
+      info->priority = (info->priority & 0xE) | (info->specialfunction & 1);
+   }
 }
 
 //////////////////////////////////////////////////////////////////////////////
 
-static u32 FASTCALL DoNothing(void *info, u32 pixel)
+static u32 FASTCALL DoNothing(UNUSED void *info, u32 pixel)
 {
    return pixel;
 }
@@ -714,14 +706,6 @@ void FASTCALL Vdp2DrawScroll(vdp2draw_struct *info, u32 *textdata, int width, in
       {
          u32 color;
 
-         // If priority of screen is less than current top pixel and per
-         // pixel priority isn't used, skip it
-         if (Vdp2GetPixelPriority(textdata[0]) > info->priority)
-         {
-            textdata++;
-            continue;
-         }
-
          // See if screen position is clipped, if it isn't, continue
          // Window 0
          if (!TestWindow(info->wctl, 0x2, 0x1, &clip[0], i, j))
@@ -748,6 +732,14 @@ void FASTCALL Vdp2DrawScroll(vdp2draw_struct *info, u32 *textdata, int width, in
             Vdp2MapCalcXY(info, &x, &y, &sinfo);
          }
 
+         // If priority of screen is less than current top pixel and per
+         // pixel priority isn't used, skip it
+         if (Vdp2GetPixelPriority(textdata[0]) > info->priority)
+         {
+            textdata++;
+            continue;
+         }
+
          if (!Vdp2FetchPixel(info, x, y, &color))
          {
             textdata++;
@@ -823,14 +815,6 @@ static void FASTCALL Vdp2DrawRotationFP(vdp2draw_struct *info, vdp2rotationparam
             for (i = 0; i < vdp2width; i++)
             {
                u32 color;
- 
-               // If priority of screen is less than current top pixel and per
-               // pixel priority isn't used, skip it
-               if (Vdp2GetPixelPriority(textdata[0]) > info->priority)
-               {
-                  textdata++;
-                  continue;
-               }
 
                x = GenerateRotatedXPosFP(p, i, xmul, ymul, C) & sinfo.xmask;
                y = GenerateRotatedYPosFP(p, i, xmul, ymul, F) & sinfo.ymask;
@@ -842,6 +826,14 @@ static void FASTCALL Vdp2DrawRotationFP(vdp2draw_struct *info, vdp2rotationparam
                   // Tile
                   Vdp2MapCalcXY(info, &x, &y, &sinfo);
                }
+ 
+               // If priority of screen is less than current top pixel and per
+               // pixel priority isn't used, skip it
+               if (Vdp2GetPixelPriority(textdata[0]) > info->priority)
+               {
+                  textdata++;
+                  continue;
+               }
 
                // Fetch pixel
                if (!Vdp2FetchPixel(info, x, y, &color))
@@ -888,14 +880,6 @@ static void FASTCALL Vdp2DrawRotationFP(vdp2draw_struct *info, vdp2rotationparam
          {
             u32 color;
 
-            // If priority of screen is less than current top pixel and per
-            // pixel priority isn't used, skip it
-            if (Vdp2GetPixelPriority(textdata[0]) > info->priority)
-            {
-               textdata++;
-               continue;
-            }
-
             if (p->deltaKAx != 0)
             {
                Vdp2ReadCoefficientFP(p,
@@ -922,6 +906,14 @@ static void FASTCALL Vdp2DrawRotationFP(vdp2draw_struct *info, vdp2rotationparam
                Vdp2MapCalcXY(info, &x, &y, &sinfo);
             }
 
+            // If priority of screen is less than current top pixel and per
+            // pixel priority isn't used, skip it
+            if (Vdp2GetPixelPriority(textdata[0]) > info->priority)
+            {
+               textdata++;
+               continue;
+            }
+
             // Fetch pixel
             if (!Vdp2FetchPixel(info, x, y, &color))
             {
@@ -1075,7 +1067,7 @@ static void Vdp2DrawNBG0(void)
    ReadVdp2ColorOffset(&info, 0x1, 0x1);
    info.priority = nbg0priority;
 
-   if (!(info.enable & vdp2disptoggle))
+   if (!(info.enable & Vdp2External.disptoggle))
       return;
 
    ReadMosaicData(&info, 0x1);
@@ -1141,7 +1133,7 @@ static void Vdp2DrawNBG1(void)
    info.priority = nbg1priority;
    info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2NBG1PlaneAddr;
 
-   if (!(info.enable & vdp2disptoggle))
+   if (!(info.enable & Vdp2External.disptoggle))
       return;
 
    ReadMosaicData(&info, 0x2);
@@ -1179,7 +1171,7 @@ static void Vdp2DrawNBG2(void)
    info.priority = nbg2priority;
    info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2NBG2PlaneAddr;
 
-   if (!(info.enable & vdp2disptoggle))
+   if (!(info.enable & Vdp2External.disptoggle))
       return;
 
    ReadMosaicData(&info, 0x4);
@@ -1219,7 +1211,7 @@ static void Vdp2DrawNBG3(void)
    info.priority = nbg3priority;
    info.PlaneAddr = (void FASTCALL (*)(void *, int))&Vdp2NBG3PlaneAddr;
 
-   if (!(info.enable & vdp2disptoggle))
+   if (!(info.enable & Vdp2External.disptoggle))
       return;
 
    ReadMosaicData(&info, 0x8);
@@ -1239,7 +1231,7 @@ static void Vdp2DrawRBG0(void)
 
    info.enable = Vdp2Regs->BGON & 0x10;
    info.priority = rbg0priority;
-   if (!(info.enable & vdp2disptoggle))
+   if (!(info.enable & Vdp2External.disptoggle))
       return;
    info.transparencyenable = !(Vdp2Regs->BGON & 0x1000);
    info.specialprimode = (Vdp2Regs->SFPRMD >> 8) & 0x3;
@@ -1383,7 +1375,10 @@ int VIDSoftInit(void)
 void VIDSoftDeInit(void)
 {
    if (dispbuffer)
+   {
       free(dispbuffer);
+      dispbuffer = NULL;
+   }
 
    if (vdp1framebuffer[0])
       free(vdp1framebuffer[0]);
@@ -2395,9 +2390,8 @@ void VIDSoftVdp1PolygonDraw(void) {
 
 //////////////////////////////////////////////////////////////////////////////
 
-int INLINE ClipLine(int *x1, int *y1, int *x2, int *y2)
+INLINE int ClipLine(int *x1, int *y1, int *x2, int *y2)
 {
-   // rewrite me
    int point1vis=0;
    int point2vis=0;
 
@@ -2423,7 +2417,28 @@ int INLINE ClipLine(int *x1, int *y1, int *x2, int *y2)
    if (point1vis == 0 && point2vis == 0)
       return 0;
 
-   // Should be doing some clipping or something here
+   if (point1vis == 0)
+   {
+      if (*x1 < vdp1clipxstart)
+          *x1 = vdp1clipxstart;
+      else if (*x1 > vdp1clipxend)
+          *x1 = vdp1clipxend;
+      if (*y1 < vdp1clipystart)
+          *y1 = vdp1clipystart;
+      else if (*y1 > vdp1clipyend)
+          *y1 = vdp1clipyend;
+   }
+   else
+   {
+      if (*x2 < vdp1clipxstart)
+          *x2 = vdp1clipxstart;
+      else if (*x2 > vdp1clipxend)
+          *x2 = vdp1clipxend;
+      if (*y2 < vdp1clipystart)
+          *y2 = vdp1clipystart;
+      else if (*y2 > vdp1clipyend)
+          *y2 = vdp1clipyend;
+   }
 
    return 1;
 }
@@ -2557,6 +2572,11 @@ void VIDSoftVdp1UserClipping(void)
    Vdp1Regs->userclipX2 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x14);
    Vdp1Regs->userclipY2 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x16);
 
+   vdp1clipxstart = Vdp1Regs->userclipX1;
+   vdp1clipxend = Vdp1Regs->userclipX2;
+   vdp1clipystart = Vdp1Regs->userclipY1;
+   vdp1clipyend = Vdp1Regs->userclipY2;
+
    // This needs work
    if (vdp1clipxstart > Vdp1Regs->systemclipX1)
       vdp1clipxstart = Vdp1Regs->userclipX1;
@@ -2583,8 +2603,8 @@ void VIDSoftVdp1UserClipping(void)
 
 void VIDSoftVdp1SystemClipping(void)
 {
-   Vdp1Regs->systemclipX1 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0xC);
-   Vdp1Regs->systemclipY1 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0xE);
+   Vdp1Regs->systemclipX1 = 0;
+   Vdp1Regs->systemclipY1 = 0;
    Vdp1Regs->systemclipX2 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x14);
    Vdp1Regs->systemclipY2 = T1ReadWord(Vdp1Ram, Vdp1Regs->addr + 0x16);
 
@@ -2951,41 +2971,6 @@ void FASTCALL VIDSoftVdp2SetPriorityRBG0(int priority)
 
 //////////////////////////////////////////////////////////////////////////////
 
-void VIDSoftVdp2ToggleDisplayNBG0(void)
-{
-   vdp2disptoggle ^= 0x1;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDSoftVdp2ToggleDisplayNBG1(void)
-{
-   vdp2disptoggle ^= 0x2;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDSoftVdp2ToggleDisplayNBG2(void)
-{
-   vdp2disptoggle ^= 0x4;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDSoftVdp2ToggleDisplayNBG3(void)
-{
-   vdp2disptoggle ^= 0x8;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
-void VIDSoftVdp2ToggleDisplayRBG0(void)
-{
-   vdp2disptoggle ^= 0x10;
-}
-
-//////////////////////////////////////////////////////////////////////////////
-
 void VIDSoftOnScreenDebugMessage(char *string, ...)
 {
    va_list arglist;
