@@ -37,7 +37,7 @@
 #include "../debug.h"
 #include "cheats.h"
 #include "../m68kcore.h"
-#ifndef _MSC_VER
+#ifdef NOC68K
 #include "../m68kc68k.h"
 #endif
 //#include "../m68khle.h"
@@ -114,7 +114,7 @@ NULL
 
 M68K_struct *M68KCoreList[] = {
 &M68KDummy,
-#ifndef _MSC_VER
+#ifndef NOC68K
 &M68KC68K,
 #endif
 //&M68KHLE,
@@ -188,7 +188,11 @@ int YuiSetVideoMode(int width, int height, int bpp, int fullscreen)
           ChangeDisplaySettings(NULL,0);
           ShowCursor(TRUE);
           fullscreen = FALSE;
+          style = WS_OVERLAPPED | WS_CAPTION | WS_SYSMENU | WS_THICKFRAME | WS_MINIMIZEBOX;
+          exstyle = WS_EX_APPWINDOW | WS_EX_WINDOWEDGE;
           SetMenu(YabWin, YabMenu);
+          width=windowwidth;
+          height=windowheight;
        }
        else
        {
@@ -450,7 +454,7 @@ DWORD WINAPI YabauseEmulate(LPVOID arg)
    else
       yinit.cdcoretype = CDCORE_ISO;
    //yinit.m68kcoretype = M68KCORE_HLE;
-#ifdef _MSC_VER
+#ifdef NOC68K
    yinit.m68kcoretype = M68KCORE_DEFAULT;
 #else
    yinit.m68kcoretype = M68KCORE_C68K;
@@ -575,6 +579,56 @@ void YuiPrintUsage()
 
 //////////////////////////////////////////////////////////////////////////////
 
+int ParseStringEmbeddedSpaces(char *out)
+{
+   char *argv;
+   
+   if ((argv = strtok(NULL, " ")) != NULL)
+   {      
+      if (argv[0] == '\"')
+      {
+         strcpy(out, argv+1);
+
+         if ((argv = strtok(NULL, "\"")) != NULL)
+         {
+            strcat(out, " ");
+            strcat(out, argv);
+         }
+      }
+      else if (out != NULL)
+         strcpy(out, argv);
+      return TRUE;
+   }
+   return FALSE;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
+int ParseStringEmbeddedSpaces2(char *out, char *in)
+{
+   char *argv;
+   char tempstr[MAX_PATH];
+
+   if (sscanf(strchr(in, '=')+1, "%[^\n]", tempstr) == 0)
+      return FALSE;
+
+   if (tempstr[0] == '\"')
+   {
+      strcpy(out, tempstr+1);
+
+      if ((argv = strtok(NULL, "\"")) != NULL)
+      {
+         strcat(out, " ");
+         strcat(out, argv);
+      }
+   }
+   else if (out != NULL)
+      strcpy(out, tempstr);
+   return TRUE;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
 int YuiInit(LPSTR lpCmdLine)
 {
    MSG                         msg;
@@ -591,8 +645,9 @@ int YuiInit(LPSTR lpCmdLine)
    char *argv=NULL;
    int forcecdpath=1;
    char filename[MAX_PATH];
-   u32 addr;
+   u32 addr=0;
    int loadexec=0;
+   char *cmddup;
 
    memset(&iccs, 0, sizeof(INITCOMMONCONTROLSEX));
    iccs.dwSize = sizeof(INITCOMMONCONTROLSEX);
@@ -615,7 +670,8 @@ int YuiInit(LPSTR lpCmdLine)
 
 #ifndef NO_CLI
    // Just handle the basic args
-   argv = strtok(lpCmdLine, " ");
+   cmddup = strdup(lpCmdLine);
+   argv = strtok(cmddup, " ");
 
    while (argv != NULL)
    {
@@ -625,12 +681,26 @@ int YuiInit(LPSTR lpCmdLine)
       {
          // Show usage
          YuiPrintUsage();
+         free(cmddup);
          return 0;
       }
-      else if ((strcmp(argv, "-i") == 0 && strtok(NULL, " \"")) ||
-                strstr(argv, "--iso=") ||
-               (strcmp(argv, "-c") == 0 && strtok(NULL, " \"")) ||
-                strstr(argv, "--cdrom="))
+      else if (strcmp(argv, "-i") == 0 ||
+               strcmp(argv, "-c") == 0)
+      {
+         if ((argv = strtok(NULL, " ")) != NULL)
+         {
+            if (argv[0] == '\"')
+            {
+               if ((argv = strtok(NULL, "\"")) == NULL)
+                  break;
+            }
+            forcecdpath = 0;
+            break;
+         }
+         break;
+      }
+      else if (strstr(argv, "--iso=") ||
+               strstr(argv, "--cdrom="))
       {
          forcecdpath = 0;
          break;
@@ -638,6 +708,8 @@ int YuiInit(LPSTR lpCmdLine)
 
       argv = strtok(NULL, " ");
    }
+
+   free(cmddup);
 #endif
 
    if (GetPrivateProfileString("General", "CDROMDrive", "", cdrompath, MAX_PATH, inifilename) == 0)
@@ -825,23 +897,22 @@ int YuiInit(LPSTR lpCmdLine)
    yabwiny = atoi(tempstr);
 
 #ifndef NO_CLI
+   cmddup = strdup(lpCmdLine);
    // Now that all the ini stuff is done, continue grabbing args
-   argv = strtok(lpCmdLine, " ");
+   argv = strtok(cmddup, " ");
 
    while (argv != NULL)
    {
       if (strcmp(argv, "-b") == 0 && (argv = strtok(NULL, " ")))
-         strcpy(biosfilename, argv);
+         ParseStringEmbeddedSpaces(biosfilename);
       else if (strstr(argv, "--bios="))
-         sscanf(strchr(argv, '=')+1, "%[^\n]", biosfilename);
-      else if (strcmp(argv, "-i") == 0 && (argv = strtok(NULL, " ")))
-         strcpy(cdrompath, argv);
-      else if (strstr(argv, "--iso="))
-         sscanf(strchr(argv, '=')+1, "%[^\n]", cdrompath);
-      else if (strcmp(argv, "-c") == 0 && (argv = strtok(NULL, " ")))
-         strcpy(cdrompath, argv);
-      else if (strstr(argv, "--cdrom="))
-         sscanf(strchr(argv, '=')+1, "%[^\n]", cdrompath);
+         ParseStringEmbeddedSpaces2(biosfilename, argv);
+      else if (strcmp(argv, "-i") == 0 || 
+               strcmp(argv, "-c") == 0)
+         ParseStringEmbeddedSpaces(cdrompath);
+      else if (strstr(argv, "--iso=") || 
+               strstr(argv, "--cdrom="))
+         ParseStringEmbeddedSpaces2(cdrompath, argv);
       else if (strcmp(argv, "-ns") == 0 ||
                strcmp(argv, "--nosound") == 0)
          sndcoretype = SNDCORE_DUMMY;
@@ -850,10 +921,9 @@ int YuiInit(LPSTR lpCmdLine)
          usefullscreenonstartup = TRUE;
       else if (strstr(argv, "--binary="))
       {
-         int count;
          char *p;
         
-         if ((count = sscanf(strchr(argv, '=')+1, "%[^\n]", filename)) == 0)
+         if (!ParseStringEmbeddedSpaces2(filename, argv))
             continue;
 
          p = strrchr(filename, ':')+1;
@@ -875,6 +945,8 @@ int YuiInit(LPSTR lpCmdLine)
       }
       argv = strtok(NULL, " ");
    }
+
+   free(cmddup);
 #endif
 
    // Figure out how much of the screen is useable
@@ -939,7 +1011,7 @@ YabauseSetup:
    else
       yinit.cdcoretype = CDCORE_ISO;
    //yinit.m68kcoretype = M68KCORE_HLE;
-#ifdef _MSC_VER
+#ifdef NOC68K
    yinit.m68kcoretype = M68KCORE_DEFAULT;
 #else
    yinit.m68kcoretype = M68KCORE_C68K;
@@ -963,7 +1035,7 @@ YabauseSetup:
       {
          nocorechange = 1;
 
-         if (DialogBox(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_SETTINGS), NULL, (DLGPROC)SettingsDlgProc) != TRUE)
+         if (DialogBox(GetModuleHandle(NULL), MAKEINTRESOURCE(IDD_SETTINGS), YabWin, (DLGPROC)SettingsDlgProc) != TRUE)
          {
             // exit program with error
             MessageBox (NULL, "yabause.ini must be properly setup before program can be used.", "Error",  MB_OK | MB_ICONINFORMATION);
@@ -1073,6 +1145,9 @@ YabauseSetup:
 
 LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
 {
+   DIDEVCAPS didc;
+   int i;
+
    switch (uMsg)
    {
       case WM_COMMAND:
@@ -1262,6 +1337,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
                SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd,
                         "Yabause Save State files\0*.YSS\0All Files\0*.*\0",
                         yssfilename, sizeof(yssfilename));
+               ofn.lpstrDefExt = "YSS";
 
                if (GetSaveFileName(&ofn))
                {
@@ -1299,8 +1375,10 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
             case IDM_SAVESTATE_F8:
             case IDM_SAVESTATE_F9:
             case IDM_SAVESTATE_F10:
+               YuiTempPause();
                if (YabSaveStateSlot(ysspath, LOWORD(wParam)-IDM_SAVESTATE_F2) != 0)
-                  MessageBox (hWnd, "Couldn't load state file", "Error",  MB_OK | MB_ICONINFORMATION);
+                  MessageBox (hWnd, "Couldn't save state file", "Error",  MB_OK | MB_ICONINFORMATION);
+               YuiTempUnPause();
                break;
             case IDM_LOADSTATE_F2:
             case IDM_LOADSTATE_F3:
@@ -1311,8 +1389,10 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
             case IDM_LOADSTATE_F8:
             case IDM_LOADSTATE_F9:
             case IDM_LOADSTATE_F10:
+               YuiTempPause();
                if (YabLoadStateSlot(ysspath, LOWORD(wParam)-IDM_LOADSTATE_F2) != 0)
                   MessageBox (hWnd, "Couldn't load state file", "Error",  MB_OK | MB_ICONINFORMATION);
+               YuiTempUnPause();
                break;
             case IDM_CAPTURESCREEN:
             {
@@ -1322,7 +1402,7 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
                SetupOFN(&ofn, OFN_DEFAULTSAVE, hWnd,
                        "Bitmap Files\0*.BMP\0All Files\0*.*\0",
                        bmpfilename, sizeof(bmpfilename));
-               ofn.lpstrDefExt = "bmp";
+               ofn.lpstrDefExt = "BMP";
 
                if (GetSaveFileName(&ofn))
                {
@@ -1387,18 +1467,46 @@ LRESULT CALLBACK WindowProc(HWND hWnd,UINT uMsg,WPARAM wParam,LPARAM lParam)
              SpeedThrottleDisable();
          return 0L;
       }
-#ifndef USETHREADS
       case WM_ENTERMENULOOP:
       {
+#ifndef USETHREADS
          ScspMuteAudio();
+#endif
+         for (i = 0; i < 12; i++)
+         {
+            if (paddevice[i].lpDIDevice)
+            {
+               didc.dwSize = sizeof(DIDEVCAPS);
+
+               if (IDirectInputDevice8_GetCapabilities(paddevice[i].lpDIDevice, &didc) != DI_OK)
+                  continue;
+
+               if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_MOUSE)
+                  IDirectInputDevice8_Unacquire(paddevice[i].lpDIDevice);
+            }
+         }
          return 0L;
       }
       case WM_EXITMENULOOP:
       {
+#ifndef USETHREADS
          ScspUnMuteAudio();
+#endif
+         for (i = 0; i < 12; i++)
+         {
+            if (paddevice[i].lpDIDevice)
+            {
+               didc.dwSize = sizeof(DIDEVCAPS);
+
+               if (IDirectInputDevice8_GetCapabilities(paddevice[i].lpDIDevice, &didc) != DI_OK)
+                  continue;
+
+               if (GET_DIDEVICE_TYPE(didc.dwDevType) == DI8DEVTYPE_MOUSE)
+                  IDirectInputDevice8_Acquire(paddevice[i].lpDIDevice);
+            }
+         }
          return 0L;
       }
-#endif
       case WM_MOVE:
       {
          RECT rect;
