@@ -888,6 +888,7 @@ LRESULT CALLBACK VDP1DebugDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
          }
 
          vdp1texturew = vdp1textureh = 1;
+         EnableWindow(GetDlgItem(hDlg, IDC_VDP1SAVEBMPBT), vdp1texture ? TRUE : FALSE);
 
          return TRUE;
       }
@@ -912,6 +913,7 @@ LRESULT CALLBACK VDP1DebugDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
                         free(vdp1texture);
 
                      vdp1texture = Vdp1DebugTexture(cursel, &vdp1texturew, &vdp1textureh);
+                     EnableWindow(GetDlgItem(hDlg, IDC_VDP1SAVEBMPBT), vdp1texture ? TRUE : FALSE);
                      InvalidateRect(hDlg, NULL, FALSE);
                      UpdateWindow(hDlg);
 
@@ -928,8 +930,9 @@ LRESULT CALLBACK VDP1DebugDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
                SetupOFN(&ofn, OFN_DEFAULTSAVE, hDlg,
                         "Bitmap Files\0*.BMP\0All Files\0*.*\0",
                         filename, sizeof(filename));
+               ofn.lpstrDefExt = "BMP";
 
-               if (GetSaveFileName(&ofn))
+               if (vdp1texture && GetSaveFileName(&ofn))
                   SaveBitmap(filename, vdp1texturew, vdp1textureh, vdp1texture);
 
                return TRUE;
@@ -958,7 +961,7 @@ LRESULT CALLBACK VDP1DebugDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
          GetClientRect(GetDlgItem(hDlg, IDC_VDP1TEXTET), &rect);
          FillRect(hdc, &rect, (HBRUSH)GetStockObject(BLACK_BRUSH));
 
-         if (vdp1texture == NULL)
+         if (vdp1texture == NULL || vdp1texturew == 0 || vdp1textureh == 0)
          {
             SetBkColor(hdc, RGB(0,0,0));
             SetTextColor(hdc, RGB(255,255,255));
@@ -1032,6 +1035,7 @@ LRESULT CALLBACK VDP2ViewerDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
          SendDlgItemMessage(hDlg, IDC_VDP2SCREENCB, CB_SETCURSEL, 0, 0);
 
          vdp2texture = Vdp2DebugTexture(0, -1, 0x00FF00FF, &width, &height);
+         EnableWindow(GetDlgItem(hDlg, IDC_VDP2SAVEBMPBT), vdp2texture ? TRUE : FALSE);
          return TRUE;
       }
       case WM_COMMAND:
@@ -1050,6 +1054,8 @@ LRESULT CALLBACK VDP2ViewerDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
                         free(vdp2texture);
 
                      vdp2texture = Vdp2DebugTexture(cursel, -1, 0x00FF00FF, &width, &height);
+                     EnableWindow(GetDlgItem(hDlg, IDC_VDP2SAVEBMPBT), vdp2texture ? TRUE : FALSE);
+
                      InvalidateRect(hDlg, NULL, FALSE);
                      UpdateWindow(hDlg);
                      return TRUE;
@@ -1064,8 +1070,9 @@ LRESULT CALLBACK VDP2ViewerDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
                OPENFILENAME ofn;
 
                SetupOFN(&ofn, OFN_DEFAULTSAVE, hDlg,
-                        "All Files\0*.*\0Bitmap Files\0*.BMP\0",
+                        "Bitmap Files\0*.BMP\0All Files\0*.*\0",
                         filename, sizeof(filename));
+               ofn.lpstrDefExt = "BMP";
 
                if (GetSaveFileName(&ofn))
                   SaveBitmap(filename, width, height, vdp2texture);
@@ -1154,7 +1161,7 @@ LRESULT CALLBACK VDP2DebugDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
    {
       case WM_INITDIALOG:
       {
-         char tempstr[2048];
+         char tempstr[VDP2_DEBUG_STRING_SIZE];
          int isscrenabled;
 
          // is NBG0/RBG1 enabled?
@@ -1840,9 +1847,10 @@ LRESULT CALLBACK SCSPDebugDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
 
                // setup ofn structure
                SetupOFN(&ofn, OFN_DEFAULTSAVE, hDlg,
-                        "All Files\0*.*\0WAV Files\0*.WAV\0",
+                        "WAV Files\0*.WAV\0All Files\0*.*\0",
                         tempstr, sizeof(tempstr));
- 
+               ofn.lpstrDefExt = "WAV";
+
                if (GetSaveFileName(&ofn))
                   ScspSlotDebugAudioSaveWav(cursel, tempstr);
 
@@ -1858,8 +1866,9 @@ LRESULT CALLBACK SCSPDebugDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
 
                // setup ofn structure
                SetupOFN(&ofn, OFN_DEFAULTSAVE, hDlg,
-                        "All Files\0*.*\0Binary Files\0*.BIN\0",
+                        "Binary Files\0*.BIN\0All Files\0*.*\0",
                         tempstr, sizeof(tempstr));
+               ofn.lpstrDefExt = "BIN";
 
                if (GetSaveFileName(&ofn))
                   ScspSlotDebugSaveRegisters(cursel, tempstr);
@@ -2398,9 +2407,10 @@ LRESULT CALLBACK LogDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam,
 
                // setup ofn structure
                SetupOFN(&ofn, OFN_DEFAULTSAVE, hDlg,
-                        "All Files\0*.*\0Text Files\0*.txt\0",
+                        "Text Files\0*.txt\0All Files\0*.*\0",
                         logfilename, sizeof(logfilename));
- 
+               ofn.lpstrDefExt = "TXT";
+
                if (GetSaveFileName(&ofn))
                {
                   FILE *fp=fopen(logfilename, "wb");
